==> blancoOmegatUtil-0.0.9-src.zip: src/blanco/omegat/utilmessage/BlancoOmegatUtilMessageResourceBundle.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * \[Xoh`쐬ꂽ\[XohNXB
 */
package blanco.omegat.utilmessage;

import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * \[Xoh`[BlancoOmegatUtilMessage/bZ[W`[BlancoOmegatUtil]Iɗp郊\[XohNXB]̃\[XohNXB
 *
 * ̃NX̓\[Xoh`玩ꂽ\[XohNXłB<BR>
 */
class BlancoOmegatUtilMessageResourceBundle {
    /**
     * \[XohIuWFNgB
     *
     * IɎۂɓ͂s\[XohL܂B
     */
    private ResourceBundle fResourceBundle;

    /**
     * BlancoOmegatUtilMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoOmegatUtilMessage]AftHg̃P[AĂяõNX[_gpāA\[Xoh擾܂B
     */
    public BlancoOmegatUtilMessageResourceBundle() {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoOmegatUtilMessage");
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoOmegatUtilMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoOmegatUtilMessage]Aw肳ꂽP[AĂяõNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     */
    public BlancoOmegatUtilMessageResourceBundle(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoOmegatUtilMessage", locale);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoOmegatUtilMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoOmegatUtilMessage]Aw肳ꂽP[Aw肳ꂽNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     * @param loader NX[_̎w
     */
    public BlancoOmegatUtilMessageResourceBundle(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoOmegatUtilMessage", locale, loader);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * IɕێĂ郊\[XohIuWFNg擾܂B
     *
     * @return IɕێĂ郊\[XohIuWFNgB
     */
    public ResourceBundle getResourceBundle() {
        return fResourceBundle;
    }
}

==> blancoOmegatUtil-0.1.1-src.zip: src/blanco/omegat/utilmessage/BlancoOmegatUtilMessageResourceBundle.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * \[Xoh`쐬ꂽ\[XohNXB
 */
package blanco.omegat.utilmessage;

import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * \[Xoh`[BlancoOmegatUtilMessage/bZ[W`[BlancoOmegatUtil]Iɗp郊\[XohNXB]̃\[XohNXB
 *
 * ̃NX̓\[Xoh`玩ꂽ\[XohNXłB<BR>
 */
class BlancoOmegatUtilMessageResourceBundle {
    /**
     * \[XohIuWFNgB
     *
     * IɎۂɓ͂s\[XohL܂B
     */
    private ResourceBundle fResourceBundle;

    /**
     * BlancoOmegatUtilMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoOmegatUtilMessage]AftHg̃P[AĂяõNX[_gpāA\[Xoh擾܂B
     */
    public BlancoOmegatUtilMessageResourceBundle() {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/omegat/utilmessage/BlancoOmegatUtilMessage");
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoOmegatUtilMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoOmegatUtilMessage]Aw肳ꂽP[AĂяõNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     */
    public BlancoOmegatUtilMessageResourceBundle(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/omegat/utilmessage/BlancoOmegatUtilMessage", locale);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoOmegatUtilMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoOmegatUtilMessage]Aw肳ꂽP[Aw肳ꂽNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     * @param loader NX[_̎w
     */
    public BlancoOmegatUtilMessageResourceBundle(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/omegat/utilmessage/BlancoOmegatUtilMessage", locale, loader);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * IɕێĂ郊\[XohIuWFNg擾܂B
     *
     * @return IɕێĂ郊\[XohIuWFNgB
     */
    public ResourceBundle getResourceBundle() {
        return fResourceBundle;
    }
}
